# sphericart

This is the sphericart project.

# Building and installing

To install the C library:

```
cd src
mkdir build
cd build
cmake .. -DCMAKE_INSTALL_PREFIX=../../lib/
make install
```

To install the Python library:

```python -m pip install .```

# Using the library

To use the C and Python libraries, please see the corresponding examples.

# Contributing

See the [CONTRIBUTING](CONTRIBUTING.md) document.

# Licensing

<!--
Please go to https://choosealicense.com/licenses/ and choose a license that
fits your needs. The recommended license for a project of this type is the
Boost Software License 1.0.
-->
